@@ -1,10 +1,13 @@
-import re
-import nltk
-from nltk.tokenize import RegexpTokenizer
-from nltk.corpus import stopwords
-from nltk.stem.porter import PorterStemmer
-from gensim.models import Phrases
-from tqdm import tqdm
+import warnings
+with warnings.catch_warnings():
+    warnings.filterwarnings("ignore", category=DeprecationWarning)
+    import re
+    import nltk
+    from nltk.tokenize import RegexpTokenizer
+    from nltk.corpus import stopwords
+    from gensim.models import Phrases
+    from tqdm import tqdm
+
 
 # Text preparation
 
@@ -18,8 +21,12 @@ class Preprocessor:
 
         Args:
             text (helper variable): None
-            language (str, optional): Sets language of stopwords to be removed. Defaults to "english".
-            stop_words (bool, optional): If true, the stopwords are removed, if not, stopwords are left as they are. Defaults to True.
+
+            language (str, optional): Sets language of stopwords to be removed.
+                Defaults to "english".
+
+            stop_words (bool, optional): If true, the stopwords are removed, if
+                not, stopwords are left as they are. Defaults to True.
 
         Returns:
             [type]: [description]
@@ -72,8 +79,10 @@ class Preprocessor:
         df_temp = df.copy(deep=True)
         df_temp[column] = df_temp[column].astype(str)
 
-        df_temp.loc[:, column] = [self._text_prepare(x) for x in df_temp[column].values]
-        df_temp[column] = [item for item in df_temp[column] if not item.isdigit()]
+        df_temp.loc[:, column] = [self._text_prepare(
+            x) for x in df_temp[column].values]
+        df_temp[column] = [
+            item for item in df_temp[column] if not item.isdigit()]
 
         tokenizer = RegexpTokenizer(r"\w+")
 
@@ -86,8 +95,22 @@ class Preprocessor:
         # apply prepro func
 
     def basic_preprocessing(self, df, column, ngram_type=2):
+        """The data will be lemmatized, tokenized and the stopwords will be
+        deleted.
+
+        Args:
+            df (pd.DataFrame): Dataframe where the documents to be preprocessed
+                are stored.
+
+            column (str):  Column name of the column where docs are stored.
+
+            ngram_type (int, optional): Number of ngrams used. Defaults to 2.
+
+        Returns:
+            pd.DataFrame: DataFrame where the original docus and the
+                preprocessed documents are stored.
+        """
         df, df_txt = self._preprocessing(df=df, column=column)
-        index = list(range(len(df_txt)))
         df_txt = df_txt.reset_index()
         df_txt = df_txt.drop("index", axis=1)
         df_txt = df_txt["tokens"]
@@ -95,9 +118,6 @@ class Preprocessor:
         df = df.reset_index()
         df = df.drop("index", axis=1)
 
-
-
-
         if ngram_type == 2:
             bigram = Phrases(df_txt, min_count=10)
 
@@ -151,4 +171,5 @@ if __name__ == "__main__":
 
     data = pd.read_csv("mtsamples.csv")
     prepro = Preprocessor()
-    test = prepro.basic_preprocessing(df=data, column="transcription", ngram_type=3)
+    test = prepro.basic_preprocessing(
+        df=data, column="transcription", ngram_type=3)
